@@ -2,5 +2,5 @@ import numpy
 
 def identity_stance(arr):
     print('IDENTITY STANCE')
-    print(arr.shape())
+    print(arr.shape)
     return arr
\ No newline at end of file
